==> exit-options_23.8.tar.xz: BUILD/translations/exit-options_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="30"/>
        <source>Restart Fluxbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="32"/>
        <source>Lock Screen</source>
        <translation>锁定屏幕</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="34"/>
        <source>Log Out</source>
        <translation>注销</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="36"/>
        <source>Suspend</source>
        <translation>挂起</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="38"/>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Shutdown</source>
        <translation>关机</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <location filename="../main.cpp" line="51"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation>带有 MX Fluxbox 退出选项的弹出窗口</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>Display buttons in a vertical window</source>
        <translation>在垂直窗口中显示按钮</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>Display buttons in a horizontal window</source>
        <translation>在水平窗口中显示按钮</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Timeout duration in seconds</source>
        <translation>超时持续时间（以秒为单位）</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation>使用 -v, --vertical 垂直显示按钮
使用 -h, --horizo​​ntal 水平显示按钮。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Usage: exit-options [options]
</source>
        <translation>用法：exit-options [选项]
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Options:</source>
        <translation>选项：</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation>-h, --horizo​​ntal	 水平显示按钮的选项</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation>  -v, --vertical	 垂直显示按钮的选项</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation>  -t, --timeout &lt;sec&gt;	 超时持续时间（以秒为单位）
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation>本次使用的显示方向选项将被记住并在您下次启动应用程序时使用</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation>或者，在 ~/.config/MX-Linux/exit-options.conf 中设置选项 &apos;layout=horizo​​ntal&apos; 或 &apos;layout=vertical&apos;</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation>您可以通过在 exit-options.conf 文件中添加 IconName=/path/iconame.ext 来定义自定义图标。您重新映射的图标的名称：%1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation>可以在 exit-options.conf 文件中设置的其他选项：%1</translation>
    </message>
</context>
</TS>

==> exit-options_24.3.tar.xz: BUILD/translations/exit-options_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="30"/>
        <source>Restart Fluxbox</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="32"/>
        <source>Lock Screen</source>
        <translation>锁定屏幕</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="34"/>
        <source>Log Out</source>
        <translation>注销</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="36"/>
        <source>Suspend</source>
        <translation>挂起</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="38"/>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Shutdown</source>
        <translation>关机</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <location filename="../main.cpp" line="51"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation>带有 MX Fluxbox 退出选项的弹出窗口</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>Display buttons in a vertical window</source>
        <translation>在垂直窗口中显示按钮</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>Display buttons in a horizontal window</source>
        <translation>在水平窗口中显示按钮</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="46"/>
        <source>Timeout duration in seconds</source>
        <translation>超时持续时间（以秒为单位）</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation>使用 -v, --vertical 垂直显示按钮
使用 -h, --horizo​​ntal 水平显示按钮。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Usage: exit-options [options]
</source>
        <translation>用法：exit-options [选项]
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Options:</source>
        <translation>选项：</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation>-h, --horizo​​ntal	 水平显示按钮的选项</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation>  -v, --vertical	 垂直显示按钮的选项</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation>  -t, --timeout &lt;sec&gt;	 超时持续时间（以秒为单位）
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation>本次使用的显示方向选项将被记住并在您下次启动应用程序时使用</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation>或者，在 ~/.config/MX-Linux/exit-options.conf 中设置选项 &apos;layout=horizo​​ntal&apos; 或 &apos;layout=vertical&apos;</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation>您可以通过在 exit-options.conf 文件中添加 IconName=/path/iconame.ext 来定义自定义图标。您重新映射的图标的名称：%1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation>可以在 exit-options.conf 文件中设置的其他选项：%1</translation>
    </message>
</context>
</TS>
